INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (1,0,85,0,1);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (1,0,93,0,1);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (1,0,110,0,1);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (5,0,0,5,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (5,0,0,1,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (2,0,0,6,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (3,0,0,6,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (4,0,0,5,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (4,0,0,10,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (1,1,0,17,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (2,1,0,17,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (3,1,0,17,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (6,1,0,17,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (1,2,0,17,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (2,2,0,15,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (3,2,0,15,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (4,2,0,21,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (5,2,0,14,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (5,2,0,10,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (6,2,0,19,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (7,0,0,23,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (7,1,0,24,0);
INSERT INTO phpbb_acl_groups (group_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (7,2,0,24,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (1,'f_',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (2,'f_announce',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (3,'f_attach',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (4,'f_bbcode',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (5,'f_bump',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (6,'f_delete',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (7,'f_download',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (8,'f_edit',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (9,'f_email',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (10,'f_flash',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (11,'f_icons',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (12,'f_ignoreflood',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (13,'f_img',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (14,'f_list',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (15,'f_noapprove',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (16,'f_poll',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (17,'f_post',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (18,'f_postcount',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (19,'f_print',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (20,'f_read',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (21,'f_reply',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (22,'f_report',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (23,'f_search',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (24,'f_sigs',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (25,'f_smilies',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (26,'f_sticky',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (27,'f_subscribe',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (28,'f_user_lock',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (29,'f_vote',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (30,'f_votechg',0,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (31,'m_',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (32,'m_approve',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (33,'m_chgposter',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (34,'m_delete',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (35,'m_edit',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (36,'m_info',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (37,'m_lock',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (38,'m_merge',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (39,'m_move',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (40,'m_report',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (41,'m_split',1,1,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (42,'m_ban',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (43,'m_warn',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (44,'a_',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (45,'a_aauth',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (46,'a_attach',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (47,'a_authgroups',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (48,'a_authusers',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (49,'a_backup',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (50,'a_ban',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (51,'a_bbcode',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (52,'a_board',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (53,'a_bots',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (54,'a_clearlogs',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (55,'a_email',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (56,'a_fauth',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (57,'a_forum',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (58,'a_forumadd',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (59,'a_forumdel',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (60,'a_group',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (61,'a_groupadd',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (62,'a_groupdel',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (63,'a_icons',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (64,'a_jabber',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (65,'a_language',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (66,'a_mauth',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (67,'a_modules',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (68,'a_names',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (69,'a_phpinfo',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (70,'a_profile',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (71,'a_prune',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (72,'a_ranks',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (73,'a_reasons',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (74,'a_roles',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (75,'a_search',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (76,'a_server',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (77,'a_styles',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (78,'a_switchperm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (79,'a_uauth',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (80,'a_user',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (81,'a_userdel',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (82,'a_viewauth',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (83,'a_viewlogs',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (84,'a_words',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (85,'u_',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (86,'u_attach',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (87,'u_chgavatar',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (88,'u_chgcensors',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (89,'u_chgemail',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (90,'u_chggrp',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (91,'u_chgname',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (92,'u_chgpasswd',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (93,'u_download',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (94,'u_hideonline',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (95,'u_ignoreflood',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (96,'u_masspm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (97,'u_pm_attach',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (98,'u_pm_bbcode',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (99,'u_pm_delete',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (100,'u_pm_download',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (101,'u_pm_edit',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (102,'u_pm_emailpm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (103,'u_pm_flash',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (104,'u_pm_forward',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (105,'u_pm_img',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (106,'u_pm_printpm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (107,'u_pm_smilies',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (108,'u_readpm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (109,'u_savedrafts',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (110,'u_search',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (111,'u_sendemail',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (112,'u_sendim',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (113,'u_sendpm',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (114,'u_sig',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (115,'u_viewonline',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (116,'u_viewprofile',1,0,0);
INSERT INTO phpbb_acl_options (auth_option_id, auth_option, is_global, is_local, founder_only) VALUES (117,'u_masspm_group',1,0,0);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (1,'ROLE_ADMIN_STANDARD','ROLE_DESCRIPTION_ADMIN_STANDARD','a_',1);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (2,'ROLE_ADMIN_FORUM','ROLE_DESCRIPTION_ADMIN_FORUM','a_',3);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (3,'ROLE_ADMIN_USERGROUP','ROLE_DESCRIPTION_ADMIN_USERGROUP','a_',4);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (4,'ROLE_ADMIN_FULL','ROLE_DESCRIPTION_ADMIN_FULL','a_',2);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (5,'ROLE_USER_FULL','ROLE_DESCRIPTION_USER_FULL','u_',3);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (6,'ROLE_USER_STANDARD','ROLE_DESCRIPTION_USER_STANDARD','u_',1);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (7,'ROLE_USER_LIMITED','ROLE_DESCRIPTION_USER_LIMITED','u_',2);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (8,'ROLE_USER_NOPM','ROLE_DESCRIPTION_USER_NOPM','u_',4);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (9,'ROLE_USER_NOAVATAR','ROLE_DESCRIPTION_USER_NOAVATAR','u_',5);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (10,'ROLE_MOD_FULL','ROLE_DESCRIPTION_MOD_FULL','m_',3);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (11,'ROLE_MOD_STANDARD','ROLE_DESCRIPTION_MOD_STANDARD','m_',1);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (12,'ROLE_MOD_SIMPLE','ROLE_DESCRIPTION_MOD_SIMPLE','m_',2);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (13,'ROLE_MOD_QUEUE','ROLE_DESCRIPTION_MOD_QUEUE','m_',4);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (14,'ROLE_FORUM_FULL','ROLE_DESCRIPTION_FORUM_FULL','f_',7);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (15,'ROLE_FORUM_STANDARD','ROLE_DESCRIPTION_FORUM_STANDARD','f_',5);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (16,'ROLE_FORUM_NOACCESS','ROLE_DESCRIPTION_FORUM_NOACCESS','f_',1);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (17,'ROLE_FORUM_READONLY','ROLE_DESCRIPTION_FORUM_READONLY','f_',2);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (18,'ROLE_FORUM_LIMITED','ROLE_DESCRIPTION_FORUM_LIMITED','f_',3);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (19,'ROLE_FORUM_BOT','ROLE_DESCRIPTION_FORUM_BOT','f_',9);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (20,'ROLE_FORUM_ONQUEUE','ROLE_DESCRIPTION_FORUM_ONQUEUE','f_',8);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (21,'ROLE_FORUM_POLLS','ROLE_DESCRIPTION_FORUM_POLLS','f_',6);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (22,'ROLE_FORUM_LIMITED_POLLS','ROLE_DESCRIPTION_FORUM_LIMITED_POLLS','f_',4);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (23,'ROLE_USER_NEW_MEMBER','ROLE_DESCRIPTION_USER_NEW_MEMBER','u_',6);
INSERT INTO phpbb_acl_roles (role_id, role_name, role_description, role_type, role_order) VALUES (24,'ROLE_FORUM_NEW_MEMBER','ROLE_DESCRIPTION_FORUM_NEW_MEMBER','f_',10);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,44,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,46,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,47,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,48,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,50,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,51,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,52,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,56,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,57,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,58,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,59,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,60,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,61,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,62,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,63,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,66,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,68,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,70,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,71,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,72,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,73,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,79,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,80,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,81,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,82,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,83,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (1,84,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,44,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,47,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,48,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,56,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,57,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,58,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,59,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,66,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,71,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,79,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,82,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (2,83,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,44,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,47,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,48,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,50,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,60,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,61,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,62,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,72,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,79,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,80,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,82,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (3,83,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,44,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,45,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,46,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,47,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,48,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,49,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,50,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,51,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,52,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,53,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,54,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,55,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,56,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,57,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,58,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,59,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,60,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,61,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,62,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,63,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,64,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,65,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,66,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,67,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,68,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,69,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,70,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,71,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,72,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,73,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,74,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,75,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,76,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,77,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,78,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,79,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,80,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,81,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,82,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,83,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (4,84,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,85,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,86,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,87,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,88,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,89,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,90,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,91,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,92,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,93,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,94,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,95,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,96,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,97,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,98,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,99,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,100,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,101,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,102,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,103,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,104,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,105,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,106,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,107,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,108,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,109,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,110,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,111,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,112,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,113,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,114,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,115,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,116,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (5,117,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,85,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,86,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,87,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,88,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,89,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,92,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,93,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,94,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,96,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,97,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,98,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,99,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,100,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,101,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,102,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,105,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,106,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,107,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,108,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,109,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,110,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,111,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,112,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,113,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,114,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,116,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (6,117,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,85,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,87,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,88,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,89,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,92,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,93,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,94,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,96,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,98,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,99,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,100,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,101,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,104,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,105,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,106,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,107,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,108,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,113,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,114,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,116,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (7,117,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,85,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,87,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,88,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,89,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,92,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,93,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,94,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,96,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,108,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,113,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,114,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,116,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (8,117,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,85,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,87,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,88,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,89,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,92,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,93,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,94,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,96,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,98,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,99,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,100,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,101,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,104,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,105,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,106,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,107,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,108,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,113,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,114,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,116,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (9,117,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,31,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,32,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,33,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,34,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,35,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,36,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,37,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,38,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,39,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,40,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,41,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,42,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (10,43,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,31,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,32,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,34,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,35,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,36,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,37,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,38,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,39,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,40,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,41,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (11,43,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (12,31,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (12,34,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (12,35,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (12,36,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (12,40,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (13,31,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (13,32,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (13,35,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,2,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,3,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,5,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,6,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,10,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,11,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,12,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,15,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,16,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,26,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,28,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (14,30,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,3,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,5,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,6,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,11,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,15,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (15,30,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (16,1,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (17,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,15,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (18,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (19,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (19,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (19,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (19,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (19,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,3,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,15,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (20,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,3,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,5,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,6,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,11,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,15,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,16,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (21,30,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,1,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,4,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,7,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,8,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,9,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,13,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,14,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,15,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,16,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,17,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,18,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,19,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,20,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,21,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,22,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,23,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,24,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,25,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,27,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (22,29,1);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (23,96,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (23,113,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (23,117,0);
INSERT INTO phpbb_acl_roles_data (role_id, auth_option_id, auth_setting) VALUES (24,15,0);
INSERT INTO phpbb_acl_users (user_id, forum_id, auth_option_id, auth_role_id, auth_setting) VALUES (2,0,0,5,0);
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (1,1,'AdsBot [Google]',3,'AdsBot-Google','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (2,1,'Alexa [Bot]',4,'ia_archiver','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (3,1,'Alta Vista [Bot]',5,'Scooter/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (4,1,'Ask Jeeves [Bot]',6,'Ask Jeeves','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (5,1,'Baidu [Spider]',7,'Baiduspider','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (6,1,'Exabot [Bot]',8,'Exabot','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (7,1,'FAST Enterprise [Crawler]',9,'FAST Enterprise Crawler','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (8,1,'FAST WebCrawler [Crawler]',10,'FAST-WebCrawler/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (9,1,'Francis [Bot]',11,'http://www.neomo.de/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (10,1,'Gigabot [Bot]',12,'Gigabot/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (11,1,'Google Adsense [Bot]',13,'Mediapartners-Google/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (12,1,'Google Desktop',14,'Google Desktop','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (13,1,'Google Feedfetcher',15,'Feedfetcher-Google','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (14,1,'Google [Bot]',16,'Googlebot','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (15,1,'Heise IT-Markt [Crawler]',17,'heise-IT-Markt-Crawler','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (16,1,'Heritrix [Crawler]',18,'heritrix/1.','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (17,1,'IBM Research [Bot]',19,'ibm.com/cs/crawler','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (18,1,'ICCrawler - ICjobs',20,'ICCrawler - ICjobs','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (19,1,'ichiro [Crawler]',21,'ichiro/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (20,1,'Majestic-12 [Bot]',22,'MJ12bot/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (21,1,'Metager [Bot]',23,'MetagerBot/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (22,1,'MSN NewsBlogs',24,'msnbot-NewsBlogs/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (23,1,'MSN [Bot]',25,'msnbot/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (24,1,'MSNbot Media',26,'msnbot-media/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (26,1,'Nutch [Bot]',28,'http://lucene.apache.org/nutch/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (29,1,'Online link [Validator]',31,'online link validator','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (30,1,'psbot [Picsearch]',32,'psbot/0','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (32,1,'Sensis [Crawler]',34,'Sensis Web Crawler','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (33,1,'SEO Crawler',35,'SEO search Crawler/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (34,1,'Seoma [Crawler]',36,'Seoma [SEO Crawler]','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (35,1,'SEOSearch [Crawler]',37,'SEOsearch/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (36,1,'Snappy [Bot]',38,'Snappy/1.1 ( http://www.urltrends.com/ )','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (37,1,'Steeler [Crawler]',39,'http://www.tkl.iis.u-tokyo.ac.jp/~crawler/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (39,1,'Telekom [Bot]',41,'crawleradmin.t-info@telekom.de','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (40,1,'TurnitinBot [Bot]',42,'TurnitinBot/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (41,1,'Voyager [Bot]',43,'voyager/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (42,1,'W3 [Sitesearch]',44,'W3 SiteSearch Crawler','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (43,1,'W3C [Linkcheck]',45,'W3C-checklink/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (44,1,'W3C [Validator]',46,'W3C_Validator','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (46,1,'Yacy [Bot]',48,'yacybot','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (47,1,'Yahoo MMCrawler [Bot]',49,'Yahoo-MMCrawler/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (48,1,'Yahoo Slurp [Bot]',50,'Yahoo! DE Slurp','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (49,1,'Yahoo [Bot]',51,'Yahoo! Slurp','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (50,1,'YahooSeeker [Bot]',52,'YahooSeeker/','');
INSERT INTO phpbb_bots (bot_id, bot_active, bot_name, user_id, bot_agent, bot_ip) VALUES (51,1,'Bing [Bot]',53,'bingbot/','');
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('active_sessions','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_attachments','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_autologin','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_avatar','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_avatar_local','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_avatar_remote','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_avatar_remote_upload','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_avatar_upload','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_bbcode','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_birthdays','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_bookmarks','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_emailreuse','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_forum_notify','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_mass_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_name_chars','USERNAME_CHARS_ANY',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_namechange','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_nocensors','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_pm_attach','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_pm_report','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_post_flash','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_post_links','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_privmsg','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_quick_reply','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_bbcode','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_flash','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_img','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_links','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_sig_smilies','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_smilies','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('allow_topic_notify','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('attachment_quota','52428800',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('auth_bbcode_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('auth_flash_pm','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('auth_img_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('auth_method','db',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('auth_smilies_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_filesize','6144',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_gallery_path','images/avatars/gallery',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_max_height','90',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_max_width','90',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_min_height','20',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_min_width','20',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_path','images/avatars/upload',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('avatar_salt','phpbb_avatar',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_contact','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_disable','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_disable_msg','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_dst','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_email','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_email_form','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_email_sig','Thanks, The Management',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_hide_emails','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_startdate','1268943869',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('board_timezone','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('browser_check','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('bump_interval','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('bump_type','d',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cache_gc','7200',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cache_last_gc','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_3d_noise','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_fonts','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_foreground_noise','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_wave','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_x_grid','@DEB_CAPTCHA_X_RAND@',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_gd_y_grid','@DEB_CAPTCHA_Y_RAND@',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('captcha_plugin','phpbb_captcha_gd',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('check_attachment_content','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('check_dnsbl','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('chg_passforce','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('confirm_refresh','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cookie_domain','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cookie_name','phpbb3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cookie_path','/',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cookie_secure','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('coppa_enable','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('coppa_fax','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('coppa_mail','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('cron_lock','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('database_gc','604800',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('database_last_gc','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('dbms_version','5.5.33-1-log',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('default_dateformat','D M d, Y g:i a',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('default_lang','en',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('default_style','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('delete_time','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('display_last_edited','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('display_order','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('edit_time','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('email_check_mx','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('email_enable','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('email_function_name','mail',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('email_package_size','20',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('enable_confirm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('enable_pm_icons','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('enable_post_confirm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('enable_queue_trigger','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_enable','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_forum','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_http_auth','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_item_statistics','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_limit','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_limit_post','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_limit_topic','15',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_overall','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_overall_forums','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_overall_forums_limit','15',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_overall_topics','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_overall_topics_limit','15',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_topic','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_topics_active','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('feed_topics_new','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('flood_interval','15',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('force_server_vars','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('form_token_lifetime','7200',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('form_token_mintime','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('form_token_sid_guests','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('forward_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('forwarded_for_check','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('full_folder_action','2',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_mysql_max_word_len','254',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_mysql_min_word_len','4',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_native_common_thres','5',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_native_load_upd','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_native_max_chars','14',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('fulltext_native_min_chars','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('gzip_compress','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('hot_threshold','25',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('icons_path','images/icons',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_create_thumbnail','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_display_inlined','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_imagick','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_link_height','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_link_width','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_max_height','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_max_thumb_width','400',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_max_width','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('img_min_thumb_filesize','12000',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ip_check','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ip_login_limit_max','50',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ip_login_limit_time','21600',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ip_login_limit_use_forwarded','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_enable','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_host','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_package_size','20',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_password','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_port','5222',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_use_ssl','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('jab_username','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('last_queue_run','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_base_dn','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_email','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_password','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_port','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_server','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_uid','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_user','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ldap_user_filter','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('limit_load','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('limit_search_load','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_anon_lastread','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_birthdays','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_cpf_memberlist','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_cpf_viewprofile','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_cpf_viewtopic','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_db_lastread','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_db_track','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_jumpbox','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_moderators','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_online','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_online_guests','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_online_time','5',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_onlinetrack','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_search','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_tplcompile','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_unreads_search','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('load_user_activity','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_attachments','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_attachments_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_autologin_time','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_filesize','262144',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_filesize_pm','262144',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_login_attempts','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_name_chars','20',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_num_search_keywords','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_pass_chars','30',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_poll_options','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_chars','60000',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_font_size','200',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_img_height','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_img_width','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_smilies','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_post_urls','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_quote_depth','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_reg_attempts','5',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_chars','255',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_font_size','200',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_img_height','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_img_width','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_smilies','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('max_sig_urls','5',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('mime_triggers','body|head|html|img|plaintext|a href|pre|script|table|title',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('min_name_chars','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('min_pass_chars','6',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('min_post_chars','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('min_search_author_chars','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('new_member_group_default','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('new_member_post_limit','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('newest_user_colour','AA0000',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('newest_user_id','2',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('newest_username','',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('num_files','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('num_posts','1',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('num_topics','1',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('num_users','1',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('override_user_style','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('pass_complex','PASS_TYPE_ANY',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('pm_edit_time','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('pm_max_boxes','4',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('pm_max_msgs','50',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('pm_max_recipients','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('posts_per_page','10',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('print_pm','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('queue_interval','60',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('queue_trigger_posts','3',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('rand_seed','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('rand_seed_last_update','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('ranks_path','images/ranks',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('record_online_date','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('record_online_users','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('referer_validation','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('require_activation','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('script_path','/phpbb',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_anonymous_interval','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_block_size','250',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_gc','7200',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_indexing_state','',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_interval','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_last_gc','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_store_results','1800',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('search_type','fulltext_native',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('secure_allow_deny','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('secure_allow_empty_referer','1',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('secure_downloads','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('server_name','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('server_port','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('server_protocol','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('session_gc','3600',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('session_last_gc','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('session_length','3600',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('site_desc','Powered by Debian',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('sitename','Your new phpBB board',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smilies_path','images/smilies',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smilies_per_page','50',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_auth_method','PLAIN',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_delivery','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_host','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_password','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_port','25',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('smtp_username','',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('topics_per_page','25',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('tpl_allow_php','0',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('upload_dir_size','0',1);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('upload_icons_path','images/upload_icons',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('upload_path','files',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('version','3.0.12',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('warnings_expire_days','90',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('warnings_gc','14400',0);
INSERT INTO phpbb_config (config_name, config_value, is_dynamic) VALUES ('warnings_last_gc','0',1);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (1,'IMAGES',1,1,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (2,'ARCHIVES',0,1,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (3,'PLAIN_TEXT',0,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (4,'DOCUMENTS',0,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (5,'REAL_MEDIA',3,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (6,'WINDOWS_MEDIA',2,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (7,'FLASH_FILES',5,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (8,'QUICKTIME_MEDIA',6,0,1,'',0,'',0);
INSERT INTO phpbb_extension_groups (group_id, group_name, cat_id, allow_group, download_mode, upload_icon, max_filesize, allowed_forums, allow_in_pm) VALUES (9,'DOWNLOADABLE_FILES',0,0,1,'',0,'',0);
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (1,1,'gif');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (2,1,'png');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (3,1,'jpeg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (4,1,'jpg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (5,1,'tif');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (6,1,'tiff');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (7,1,'tga');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (8,2,'gtar');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (9,2,'gz');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (10,2,'tar');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (11,2,'zip');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (12,2,'rar');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (13,2,'ace');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (14,2,'torrent');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (15,2,'tgz');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (16,2,'bz2');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (17,2,'7z');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (18,3,'txt');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (19,3,'c');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (20,3,'h');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (21,3,'cpp');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (22,3,'hpp');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (23,3,'diz');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (24,3,'csv');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (25,3,'ini');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (26,3,'log');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (27,3,'js');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (28,3,'xml');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (29,4,'xls');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (30,4,'xlsx');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (31,4,'xlsm');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (32,4,'xlsb');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (33,4,'doc');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (34,4,'docx');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (35,4,'docm');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (36,4,'dot');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (37,4,'dotx');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (38,4,'dotm');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (39,4,'pdf');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (40,4,'ai');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (41,4,'ps');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (42,4,'ppt');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (43,4,'pptx');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (44,4,'pptm');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (45,4,'odg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (46,4,'odp');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (47,4,'ods');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (48,4,'odt');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (49,4,'rtf');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (50,5,'rm');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (51,5,'ram');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (52,6,'wma');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (53,6,'wmv');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (54,7,'swf');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (55,8,'mov');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (56,8,'m4v');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (57,8,'m4a');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (58,8,'mp4');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (59,8,'3gp');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (60,8,'3g2');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (61,8,'qt');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (62,9,'mpeg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (63,9,'mpg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (64,9,'mp3');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (65,9,'ogg');
INSERT INTO phpbb_extensions (extension_id, group_id, extension) VALUES (66,9,'ogm');
INSERT INTO phpbb_forums (forum_id, parent_id, left_id, right_id, forum_parents, forum_name, forum_desc, forum_desc_bitfield, forum_desc_options, forum_desc_uid, forum_link, forum_password, forum_style, forum_image, forum_rules, forum_rules_link, forum_rules_bitfield, forum_rules_options, forum_rules_uid, forum_topics_per_page, forum_type, forum_status, forum_posts, forum_topics, forum_topics_real, forum_last_post_id, forum_last_poster_id, forum_last_post_subject, forum_last_post_time, forum_last_poster_name, forum_last_poster_colour, forum_flags, forum_options, display_subforum_list, display_on_index, enable_indexing, enable_icons, enable_prune, prune_next, prune_days, prune_viewed, prune_freq) VALUES (1,0,1,4,'','Example Category','','',7,'','','',0,'','','','',7,'',0,0,0,1,1,1,1,2,'',972086460,'Admin','AA0000',32,0,1,1,1,1,0,0,0,0,0);
INSERT INTO phpbb_forums (forum_id, parent_id, left_id, right_id, forum_parents, forum_name, forum_desc, forum_desc_bitfield, forum_desc_options, forum_desc_uid, forum_link, forum_password, forum_style, forum_image, forum_rules, forum_rules_link, forum_rules_bitfield, forum_rules_options, forum_rules_uid, forum_topics_per_page, forum_type, forum_status, forum_posts, forum_topics, forum_topics_real, forum_last_post_id, forum_last_poster_id, forum_last_post_subject, forum_last_post_time, forum_last_poster_name, forum_last_poster_colour, forum_flags, forum_options, display_subforum_list, display_on_index, enable_indexing, enable_icons, enable_prune, prune_next, prune_days, prune_viewed, prune_freq) VALUES (2,1,2,3,'','Example Forum','This forum serves as an example','',7,'','','',0,'','','','',7,'',0,1,0,1,1,1,1,2,'Test Topic',972086460,'Admin','AA0000',32,0,1,1,1,1,0,0,0,0,0);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (1,3,0,0,'GUESTS','','',7,'',0,'',0,0,0,0,'',0,0,0,5,0);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (2,3,0,0,'REGISTERED','','',7,'',0,'',0,0,0,0,'',0,0,0,5,0);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (3,3,0,0,'REGISTERED_COPPA','','',7,'',0,'',0,0,0,0,'',0,0,0,5,0);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (4,3,0,0,'GLOBAL_MODERATORS','','',7,'',0,'',0,0,0,0,'00AA00',0,0,0,0,1);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (5,3,1,0,'ADMINISTRATORS','','',7,'',0,'',0,0,0,0,'AA0000',0,0,0,0,1);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (6,3,0,0,'BOTS','','',7,'',0,'',0,0,0,0,'9E8DA7',0,0,0,5,0);
INSERT INTO phpbb_groups (group_id, group_type, group_founder_manage, group_skip_auth, group_name, group_desc, group_desc_bitfield, group_desc_options, group_desc_uid, group_display, group_avatar, group_avatar_type, group_avatar_width, group_avatar_height, group_rank, group_colour, group_sig_chars, group_receive_pm, group_message_limit, group_max_recipients, group_legend) VALUES (7,3,0,0,'NEWLY_REGISTERED','','',7,'',0,'',0,0,0,0,'',0,0,0,5,0);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (1,'misc/fire.gif',16,16,1,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (2,'smile/redface.gif',16,16,9,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (3,'smile/mrgreen.gif',16,16,10,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (4,'misc/heart.gif',16,16,4,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (5,'misc/star.gif',16,16,2,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (6,'misc/radioactive.gif',16,16,3,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (7,'misc/thinking.gif',16,16,5,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (8,'smile/info.gif',16,16,8,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (9,'smile/question.gif',16,16,6,1);
INSERT INTO phpbb_icons (icons_id, icons_url, icons_width, icons_height, icons_order, display_on_posting) VALUES (10,'smile/alert.gif',16,16,7,1);
INSERT INTO phpbb_lang (lang_id, lang_iso, lang_dir, lang_english_name, lang_local_name, lang_author) VALUES (1,'en','en','English [GB]','English [GB]','phpBB Group');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (1,1,1,'','acp',0,1,64,'ACP_CAT_GENERAL','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (2,1,1,'','acp',1,4,17,'ACP_QUICK_ACCESS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (3,1,1,'','acp',1,18,41,'ACP_BOARD_CONFIGURATION','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (4,1,1,'','acp',1,42,49,'ACP_CLIENT_COMMUNICATION','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (5,1,1,'','acp',1,50,63,'ACP_SERVER_CONFIGURATION','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (6,1,1,'','acp',0,65,84,'ACP_CAT_FORUMS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (7,1,1,'','acp',6,66,71,'ACP_MANAGE_FORUMS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (8,1,1,'','acp',6,72,83,'ACP_FORUM_BASED_PERMISSIONS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (9,1,1,'','acp',0,85,110,'ACP_CAT_POSTING','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (10,1,1,'','acp',9,86,99,'ACP_MESSAGES','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (11,1,1,'','acp',9,100,109,'ACP_ATTACHMENTS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (12,1,1,'','acp',0,111,166,'ACP_CAT_USERGROUP','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (13,1,1,'','acp',12,112,145,'ACP_CAT_USERS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (14,1,1,'','acp',12,146,153,'ACP_GROUPS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (15,1,1,'','acp',12,154,165,'ACP_USER_SECURITY','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (16,1,1,'','acp',0,167,216,'ACP_CAT_PERMISSIONS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (17,1,1,'','acp',16,170,179,'ACP_GLOBAL_PERMISSIONS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (18,1,1,'','acp',16,180,191,'ACP_FORUM_BASED_PERMISSIONS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (19,1,1,'','acp',16,192,201,'ACP_PERMISSION_ROLES','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (20,1,1,'','acp',16,202,215,'ACP_PERMISSION_MASKS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (21,1,1,'','acp',0,217,230,'ACP_CAT_STYLES','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (22,1,1,'','acp',21,218,221,'ACP_STYLE_MANAGEMENT','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (23,1,1,'','acp',21,222,229,'ACP_STYLE_COMPONENTS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (24,1,1,'','acp',0,231,250,'ACP_CAT_MAINTENANCE','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (25,1,1,'','acp',24,232,241,'ACP_FORUM_LOGS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (26,1,1,'','acp',24,242,249,'ACP_CAT_DATABASE','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (27,1,1,'','acp',0,251,276,'ACP_CAT_SYSTEM','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (28,1,1,'','acp',27,252,255,'ACP_AUTOMATION','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (29,1,1,'','acp',27,256,267,'ACP_GENERAL_TASKS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (30,1,1,'','acp',27,268,275,'ACP_MODULE_MANAGEMENT','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (31,1,1,'','acp',0,277,278,'ACP_CAT_DOT_MODS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (32,1,1,'attachments','acp',3,19,20,'ACP_ATTACHMENT_SETTINGS','attach','acl_a_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (33,1,1,'attachments','acp',11,101,102,'ACP_ATTACHMENT_SETTINGS','attach','acl_a_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (34,1,1,'attachments','acp',11,103,104,'ACP_MANAGE_EXTENSIONS','extensions','acl_a_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (35,1,1,'attachments','acp',11,105,106,'ACP_EXTENSION_GROUPS','ext_groups','acl_a_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (36,1,1,'attachments','acp',11,107,108,'ACP_ORPHAN_ATTACHMENTS','orphan','acl_a_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (37,1,1,'ban','acp',15,155,156,'ACP_BAN_EMAILS','email','acl_a_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (38,1,1,'ban','acp',15,157,158,'ACP_BAN_IPS','ip','acl_a_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (39,1,1,'ban','acp',15,159,160,'ACP_BAN_USERNAMES','user','acl_a_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (40,1,1,'bbcodes','acp',10,87,88,'ACP_BBCODES','bbcodes','acl_a_bbcode');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (41,1,1,'board','acp',3,21,22,'ACP_BOARD_SETTINGS','settings','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (42,1,1,'board','acp',3,23,24,'ACP_BOARD_FEATURES','features','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (43,1,1,'board','acp',3,25,26,'ACP_AVATAR_SETTINGS','avatar','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (44,1,1,'board','acp',3,27,28,'ACP_MESSAGE_SETTINGS','message','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (45,1,1,'board','acp',10,89,90,'ACP_MESSAGE_SETTINGS','message','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (46,1,1,'board','acp',3,29,30,'ACP_POST_SETTINGS','post','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (47,1,1,'board','acp',3,31,32,'ACP_SIGNATURE_SETTINGS','signature','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (48,1,1,'board','acp',3,33,34,'ACP_REGISTER_SETTINGS','registration','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (49,1,1,'board','acp',4,43,44,'ACP_AUTH_SETTINGS','auth','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (50,1,1,'board','acp',4,45,46,'ACP_EMAIL_SETTINGS','email','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (51,1,1,'board','acp',5,51,52,'ACP_COOKIE_SETTINGS','cookie','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (52,1,1,'board','acp',5,53,54,'ACP_SERVER_SETTINGS','server','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (53,1,1,'board','acp',5,55,56,'ACP_SECURITY_SETTINGS','security','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (54,1,1,'board','acp',5,57,58,'ACP_LOAD_SETTINGS','load','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (55,1,1,'bots','acp',29,257,258,'ACP_BOTS','bots','acl_a_bots');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (56,1,1,'captcha','acp',3,35,36,'ACP_VC_SETTINGS','visual','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (57,1,0,'captcha','acp',3,37,38,'ACP_VC_CAPTCHA_DISPLAY','img','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (58,1,1,'database','acp',26,243,244,'ACP_BACKUP','backup','acl_a_backup');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (59,1,1,'database','acp',26,245,246,'ACP_RESTORE','restore','acl_a_backup');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (60,1,1,'disallow','acp',15,161,162,'ACP_DISALLOW_USERNAMES','usernames','acl_a_names');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (61,1,1,'email','acp',29,259,260,'ACP_MASS_EMAIL','email','acl_a_email && cfg_email_enable');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (62,1,1,'forums','acp',7,67,68,'ACP_MANAGE_FORUMS','manage','acl_a_forum');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (63,1,1,'groups','acp',14,147,148,'ACP_GROUPS_MANAGE','manage','acl_a_group');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (64,1,1,'icons','acp',10,93,94,'ACP_ICONS','icons','acl_a_icons');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (65,1,1,'icons','acp',10,95,96,'ACP_SMILIES','smilies','acl_a_icons');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (66,1,1,'inactive','acp',13,115,116,'ACP_INACTIVE_USERS','list','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (67,1,1,'jabber','acp',4,47,48,'ACP_JABBER_SETTINGS','settings','acl_a_jabber');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (68,1,1,'language','acp',29,261,262,'ACP_LANGUAGE_PACKS','lang_packs','acl_a_language');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (69,1,1,'logs','acp',25,233,234,'ACP_ADMIN_LOGS','admin','acl_a_viewlogs');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (70,1,1,'logs','acp',25,235,236,'ACP_MOD_LOGS','mod','acl_a_viewlogs');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (71,1,1,'logs','acp',25,237,238,'ACP_USERS_LOGS','users','acl_a_viewlogs');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (72,1,1,'logs','acp',25,239,240,'ACP_CRITICAL_LOGS','critical','acl_a_viewlogs');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (73,1,1,'main','acp',1,2,3,'ACP_INDEX','main','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (74,1,1,'modules','acp',30,269,270,'ACP','acp','acl_a_modules');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (75,1,1,'modules','acp',30,271,272,'UCP','ucp','acl_a_modules');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (76,1,1,'modules','acp',30,273,274,'MCP','mcp','acl_a_modules');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (77,1,1,'permission_roles','acp',19,193,194,'ACP_ADMIN_ROLES','admin_roles','acl_a_roles && acl_a_aauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (78,1,1,'permission_roles','acp',19,195,196,'ACP_USER_ROLES','user_roles','acl_a_roles && acl_a_uauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (79,1,1,'permission_roles','acp',19,197,198,'ACP_MOD_ROLES','mod_roles','acl_a_roles && acl_a_mauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (80,1,1,'permission_roles','acp',19,199,200,'ACP_FORUM_ROLES','forum_roles','acl_a_roles && acl_a_fauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (81,1,1,'permissions','acp',16,168,169,'ACP_PERMISSIONS','intro','acl_a_authusers || acl_a_authgroups || acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (82,1,0,'permissions','acp',20,203,204,'ACP_PERMISSION_TRACE','trace','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (83,1,1,'permissions','acp',18,181,182,'ACP_FORUM_PERMISSIONS','setting_forum_local','acl_a_fauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (84,1,1,'permissions','acp',18,183,184,'ACP_FORUM_MODERATORS','setting_mod_local','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (85,1,1,'permissions','acp',17,171,172,'ACP_USERS_PERMISSIONS','setting_user_global','acl_a_authusers && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (86,1,1,'permissions','acp',13,117,118,'ACP_USERS_PERMISSIONS','setting_user_global','acl_a_authusers && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (87,1,1,'permissions','acp',18,185,186,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (88,1,1,'permissions','acp',13,119,120,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (89,1,1,'permissions','acp',17,173,174,'ACP_GROUPS_PERMISSIONS','setting_group_global','acl_a_authgroups && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (90,1,1,'permissions','acp',14,149,150,'ACP_GROUPS_PERMISSIONS','setting_group_global','acl_a_authgroups && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (91,1,1,'permissions','acp',18,187,188,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (92,1,1,'permissions','acp',14,151,152,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (93,1,1,'permissions','acp',17,175,176,'ACP_ADMINISTRATORS','setting_admin_global','acl_a_aauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (94,1,1,'permissions','acp',17,177,178,'ACP_GLOBAL_MODERATORS','setting_mod_global','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (95,1,1,'permissions','acp',20,205,206,'ACP_VIEW_ADMIN_PERMISSIONS','view_admin_global','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (96,1,1,'permissions','acp',20,207,208,'ACP_VIEW_USER_PERMISSIONS','view_user_global','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (97,1,1,'permissions','acp',20,209,210,'ACP_VIEW_GLOBAL_MOD_PERMISSIONS','view_mod_global','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (98,1,1,'permissions','acp',20,211,212,'ACP_VIEW_FORUM_MOD_PERMISSIONS','view_mod_local','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (99,1,1,'permissions','acp',20,213,214,'ACP_VIEW_FORUM_PERMISSIONS','view_forum_local','acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (100,1,1,'php_info','acp',29,263,264,'ACP_PHP_INFO','info','acl_a_phpinfo');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (101,1,1,'profile','acp',13,121,122,'ACP_CUSTOM_PROFILE_FIELDS','profile','acl_a_profile');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (102,1,1,'prune','acp',7,69,70,'ACP_PRUNE_FORUMS','forums','acl_a_prune');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (103,1,1,'prune','acp',15,163,164,'ACP_PRUNE_USERS','users','acl_a_userdel');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (104,1,1,'ranks','acp',13,123,124,'ACP_MANAGE_RANKS','ranks','acl_a_ranks');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (105,1,1,'reasons','acp',29,265,266,'ACP_MANAGE_REASONS','main','acl_a_reasons');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (106,1,1,'search','acp',5,59,60,'ACP_SEARCH_SETTINGS','settings','acl_a_search');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (107,1,1,'search','acp',26,247,248,'ACP_SEARCH_INDEX','index','acl_a_search');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (108,1,1,'styles','acp',22,219,220,'ACP_STYLES','style','acl_a_styles');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (109,1,1,'styles','acp',23,223,224,'ACP_TEMPLATES','template','acl_a_styles');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (110,1,1,'styles','acp',23,225,226,'ACP_THEMES','theme','acl_a_styles');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (111,1,1,'styles','acp',23,227,228,'ACP_IMAGESETS','imageset','acl_a_styles');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (112,1,1,'update','acp',28,253,254,'ACP_VERSION_CHECK','version_check','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (113,1,1,'users','acp',13,113,114,'ACP_MANAGE_USERS','overview','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (114,1,0,'users','acp',13,125,126,'ACP_USER_FEEDBACK','feedback','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (115,1,0,'users','acp',13,127,128,'ACP_USER_PROFILE','profile','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (116,1,0,'users','acp',13,129,130,'ACP_USER_PREFS','prefs','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (117,1,0,'users','acp',13,131,132,'ACP_USER_AVATAR','avatar','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (118,1,0,'users','acp',13,133,134,'ACP_USER_RANK','rank','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (119,1,0,'users','acp',13,135,136,'ACP_USER_SIG','sig','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (120,1,0,'users','acp',13,137,138,'ACP_USER_GROUPS','groups','acl_a_user && acl_a_group');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (121,1,0,'users','acp',13,139,140,'ACP_USER_PERM','perm','acl_a_user && acl_a_viewauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (122,1,0,'users','acp',13,141,142,'ACP_USER_ATTACH','attach','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (123,1,1,'words','acp',10,97,98,'ACP_WORDS','words','acl_a_words');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (124,1,1,'users','acp',2,5,6,'ACP_MANAGE_USERS','overview','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (125,1,1,'groups','acp',2,7,8,'ACP_GROUPS_MANAGE','manage','acl_a_group');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (126,1,1,'forums','acp',2,9,10,'ACP_MANAGE_FORUMS','manage','acl_a_forum');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (127,1,1,'logs','acp',2,11,12,'ACP_MOD_LOGS','mod','acl_a_viewlogs');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (128,1,1,'bots','acp',2,13,14,'ACP_BOTS','bots','acl_a_bots');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (129,1,1,'php_info','acp',2,15,16,'ACP_PHP_INFO','info','acl_a_phpinfo');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (130,1,1,'permissions','acp',8,73,74,'ACP_FORUM_PERMISSIONS','setting_forum_local','acl_a_fauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (131,1,1,'permissions','acp',8,75,76,'ACP_FORUM_MODERATORS','setting_mod_local','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (132,1,1,'permissions','acp',8,77,78,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (133,1,1,'permissions','acp',8,79,80,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (134,1,1,'','mcp',0,1,10,'MCP_MAIN','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (135,1,1,'','mcp',0,11,18,'MCP_QUEUE','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (136,1,1,'','mcp',0,19,32,'MCP_REPORTS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (137,1,1,'','mcp',0,33,38,'MCP_NOTES','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (138,1,1,'','mcp',0,39,48,'MCP_WARN','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (139,1,1,'','mcp',0,49,56,'MCP_LOGS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (140,1,1,'','mcp',0,57,64,'MCP_BAN','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (141,1,1,'ban','mcp',140,58,59,'MCP_BAN_USERNAMES','user','acl_m_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (142,1,1,'ban','mcp',140,60,61,'MCP_BAN_IPS','ip','acl_m_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (143,1,1,'ban','mcp',140,62,63,'MCP_BAN_EMAILS','email','acl_m_ban');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (144,1,1,'logs','mcp',139,50,51,'MCP_LOGS_FRONT','front','acl_m_ || aclf_m_');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (145,1,1,'logs','mcp',139,52,53,'MCP_LOGS_FORUM_VIEW','forum_logs','acl_m_,$id');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (146,1,1,'logs','mcp',139,54,55,'MCP_LOGS_TOPIC_VIEW','topic_logs','acl_m_,$id');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (147,1,1,'main','mcp',134,2,3,'MCP_MAIN_FRONT','front','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (148,1,1,'main','mcp',134,4,5,'MCP_MAIN_FORUM_VIEW','forum_view','acl_m_,$id');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (149,1,1,'main','mcp',134,6,7,'MCP_MAIN_TOPIC_VIEW','topic_view','acl_m_,$id');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (150,1,1,'main','mcp',134,8,9,'MCP_MAIN_POST_DETAILS','post_details','acl_m_,$id || (!$id && aclf_m_)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (151,1,1,'notes','mcp',137,34,35,'MCP_NOTES_FRONT','front','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (152,1,1,'notes','mcp',137,36,37,'MCP_NOTES_USER','user_notes','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (153,1,1,'queue','mcp',135,12,13,'MCP_QUEUE_UNAPPROVED_TOPICS','unapproved_topics','aclf_m_approve');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (154,1,1,'queue','mcp',135,14,15,'MCP_QUEUE_UNAPPROVED_POSTS','unapproved_posts','aclf_m_approve');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (155,1,1,'queue','mcp',135,16,17,'MCP_QUEUE_APPROVE_DETAILS','approve_details','acl_m_approve,$id || (!$id && aclf_m_approve)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (156,1,1,'reports','mcp',136,20,21,'MCP_REPORTS_OPEN','reports','aclf_m_report');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (157,1,1,'reports','mcp',136,22,23,'MCP_REPORTS_CLOSED','reports_closed','aclf_m_report');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (158,1,1,'reports','mcp',136,24,25,'MCP_REPORT_DETAILS','report_details','acl_m_report,$id || (!$id && aclf_m_report)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (159,1,1,'warn','mcp',138,40,41,'MCP_WARN_FRONT','front','aclf_m_warn');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (160,1,1,'warn','mcp',138,42,43,'MCP_WARN_LIST','list','aclf_m_warn');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (161,1,1,'warn','mcp',138,44,45,'MCP_WARN_USER','warn_user','aclf_m_warn');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (162,1,1,'warn','mcp',138,46,47,'MCP_WARN_POST','warn_post','acl_m_warn,$id || (!$id && aclf_m_warn)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (163,1,1,'','ucp',0,1,12,'UCP_MAIN','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (164,1,1,'','ucp',0,13,22,'UCP_PROFILE','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (165,1,1,'','ucp',0,23,30,'UCP_PREFS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (166,1,1,'','ucp',0,31,42,'UCP_PM','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (167,1,1,'','ucp',0,43,48,'UCP_USERGROUPS','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (168,1,1,'','ucp',0,49,54,'UCP_ZEBRA','','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (169,1,1,'attachments','ucp',163,10,11,'UCP_MAIN_ATTACHMENTS','attachments','acl_u_attach');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (170,1,1,'groups','ucp',167,44,45,'UCP_USERGROUPS_MEMBER','membership','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (171,1,1,'groups','ucp',167,46,47,'UCP_USERGROUPS_MANAGE','manage','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (172,1,1,'main','ucp',163,2,3,'UCP_MAIN_FRONT','front','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (173,1,1,'main','ucp',163,4,5,'UCP_MAIN_SUBSCRIBED','subscribed','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (174,1,1,'main','ucp',163,6,7,'UCP_MAIN_BOOKMARKS','bookmarks','cfg_allow_bookmarks');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (175,1,1,'main','ucp',163,8,9,'UCP_MAIN_DRAFTS','drafts','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (176,1,0,'pm','ucp',166,32,33,'UCP_PM_VIEW','view','cfg_allow_privmsg');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (177,1,1,'pm','ucp',166,34,35,'UCP_PM_COMPOSE','compose','cfg_allow_privmsg');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (178,1,1,'pm','ucp',166,36,37,'UCP_PM_DRAFTS','drafts','cfg_allow_privmsg');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (179,1,1,'pm','ucp',166,38,39,'UCP_PM_OPTIONS','options','cfg_allow_privmsg');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (180,1,0,'pm','ucp',166,40,41,'UCP_PM_POPUP_TITLE','popup','cfg_allow_privmsg');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (181,1,1,'prefs','ucp',165,24,25,'UCP_PREFS_PERSONAL','personal','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (182,1,1,'prefs','ucp',165,26,27,'UCP_PREFS_POST','post','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (183,1,1,'prefs','ucp',165,28,29,'UCP_PREFS_VIEW','view','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (184,1,1,'profile','ucp',164,14,15,'UCP_PROFILE_PROFILE_INFO','profile_info','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (185,1,1,'profile','ucp',164,16,17,'UCP_PROFILE_SIGNATURE','signature','acl_u_sig');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (186,1,1,'profile','ucp',164,18,19,'UCP_PROFILE_AVATAR','avatar','cfg_allow_avatar && (cfg_allow_avatar_local || cfg_allow_avatar_remote || cfg_allow_avatar_upload || cfg_allow_avatar_remote_upload)');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (187,1,1,'profile','ucp',164,20,21,'UCP_PROFILE_REG_DETAILS','reg_details','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (188,1,1,'zebra','ucp',168,50,51,'UCP_ZEBRA_FRIENDS','friends','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (189,1,1,'zebra','ucp',168,52,53,'UCP_ZEBRA_FOES','foes','');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (190,1,1,'board','acp',3,39,40,'ACP_FEED_SETTINGS','feed','acl_a_board');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (191,1,0,'users','acp',13,143,144,'ACP_USER_WARNINGS','warnings','acl_a_user');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (192,1,1,'send_statistics','acp',5,61,62,'ACP_SEND_STATISTICS','send_statistics','acl_a_server');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (193,1,1,'permissions','acp',8,81,82,'ACP_FORUM_PERMISSIONS_COPY','setting_forum_copy','acl_a_fauth && acl_a_authusers && acl_a_authgroups && acl_a_mauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (194,1,1,'permissions','acp',18,189,190,'ACP_FORUM_PERMISSIONS_COPY','setting_forum_copy','acl_a_fauth && acl_a_authusers && acl_a_authgroups && acl_a_mauth');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (195,1,1,'pm_reports','mcp',136,26,27,'MCP_PM_REPORTS_OPEN','pm_reports','aclf_m_report');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (196,1,1,'pm_reports','mcp',136,28,29,'MCP_PM_REPORTS_CLOSED','pm_reports_closed','aclf_m_report');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (197,1,1,'pm_reports','mcp',136,30,31,'MCP_PM_REPORT_DETAILS','pm_report_details','aclf_m_report');
INSERT INTO phpbb_modules (module_id, module_enabled, module_display, module_basename, module_class, parent_id, left_id, right_id, module_langname, module_mode, module_auth) VALUES (198,1,1,'board','acp',10,91,92,'ACP_POST_SETTINGS','post','acl_a_board');
INSERT INTO phpbb_posts (post_id, topic_id, forum_id, poster_id, icon_id, poster_ip, post_time, post_approved, post_reported, enable_bbcode, enable_smilies, enable_magic_url, enable_sig, post_username, post_subject, post_text, post_checksum, post_attachment, bbcode_bitfield, bbcode_uid, post_postcount, post_edit_time, post_edit_reason, post_edit_user, post_edit_count, post_edit_locked) VALUES (1,1,2,2,0,'127.0.0.1',972086460,1,0,1,1,1,1,'','Test Toptic','First Post!','5dd683b17f641daf84c040bfefc58ce9',0,'','',1,0,'',0,0,0);
INSERT INTO phpbb_ranks (rank_id, rank_title, rank_min, rank_special, rank_image) VALUES (1,'Site Admin',0,1,'');
INSERT INTO phpbb_reports_reasons (reason_id, reason_title, reason_description, reason_order) VALUES (1,'warez','{L_REPORT_WAREZ}',1);
INSERT INTO phpbb_reports_reasons (reason_id, reason_title, reason_description, reason_order) VALUES (2,'spam','{L_REPORT_SPAM}',2);
INSERT INTO phpbb_reports_reasons (reason_id, reason_title, reason_description, reason_order) VALUES (3,'off_topic','{L_REPORT_OFF_TOPIC}',3);
INSERT INTO phpbb_reports_reasons (reason_id, reason_title, reason_description, reason_order) VALUES (4,'other','{L_REPORT_OTHER}',4);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (1,':D',':-D','icon_e_biggrin.gif',15,17,1,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (2,':-D',':-D','icon_e_biggrin.gif',15,17,2,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (3,':grin:',':-D','icon_e_biggrin.gif',15,17,3,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (4,':)',':-)','icon_e_smile.gif',15,17,4,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (5,':-)',':-)','icon_e_smile.gif',15,17,5,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (6,':smile:',':-)','icon_e_smile.gif',15,17,6,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (7,';)',';-)','icon_e_wink.gif',15,17,7,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (8,';-)',';-)','icon_e_wink.gif',15,17,8,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (9,':wink:',';-)','icon_e_wink.gif',15,17,9,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (10,':(',':-(','icon_e_sad.gif',15,17,10,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (11,':-(',':-(','icon_e_sad.gif',15,17,11,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (12,':sad:',':-(','icon_e_sad.gif',15,17,12,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (13,':o',':-O','icon_e_surprised.gif',15,19,13,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (14,':-o',':-O','icon_e_surprised.gif',15,19,14,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (15,':eek:',':-O','icon_e_surprised.gif',15,19,15,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (16,':shock:',':-O','icon_eek.gif',15,15,16,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (17,':?',':-/','icon_e_confused.gif',15,17,17,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (18,':-?',':-/','icon_e_confused.gif',15,17,18,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (19,':???:',':-/','icon_e_confused.gif',15,17,19,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (20,'8-)','8-)','icon_cool.gif',15,15,20,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (21,':cool:','8-)','icon_cool.gif',15,15,21,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (22,':lol:',':-D','icon_lol.gif',15,15,22,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (23,':x','>:-(','icon_mad.gif',15,15,23,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (24,':-x','>:-(','icon_mad.gif',15,15,24,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (25,':mad:','>:-(','icon_mad.gif',15,15,25,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (26,':P',':-P','icon_razz.gif',15,15,26,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (27,':-P',':-P','icon_razz.gif',15,15,27,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (28,':razz:',':-P','icon_razz.gif',15,15,28,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (29,':oops:',':-|','icon_redface.gif',15,15,29,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (30,':cry:',':~(','icon_cry.gif',15,15,30,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (31,':evil:','>:-)','icon_evil.gif',15,15,31,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (32,':twisted:','>:->','icon_twisted.gif',15,15,32,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (33,':roll:',':-/','icon_rolleyes.gif',15,15,33,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (34,':!:','!','icon_exclaim.gif',15,15,34,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (35,':?:','?','icon_question.gif',15,15,35,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (36,':idea:','(!)','icon_idea.gif',15,15,36,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (37,':arrow:','->','icon_arrow.gif',15,15,37,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (38,':|',':-|','icon_neutral.gif',15,15,38,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (39,':-|',':-|','icon_neutral.gif',15,15,39,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (40,':mrgreen:','8-D','icon_mrgreen.gif',15,15,40,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (41,':geek:','8-{','icon_e_geek.gif',17,17,41,1);
INSERT INTO phpbb_smilies (smiley_id, code, emotion, smiley_url, smiley_width, smiley_height, smiley_order, display_on_posting) VALUES (42,':ugeek:','88-{','icon_e_ugeek.gif',19,18,42,1);
INSERT INTO phpbb_styles (style_id, style_name, style_copyright, style_active, template_id, theme_id, imageset_id) VALUES (1,'prosilver','&copy; phpBB Group',1,1,1,1);
INSERT INTO phpbb_styles_imageset (imageset_id, imageset_name, imageset_copyright, imageset_path) VALUES (1,'prosilver','&copy; phpBB Group','prosilver');
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (1,'site_logo','site_logo.gif','',52,139,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (2,'forum_link','forum_link.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (3,'forum_read','forum_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (4,'forum_read_locked','forum_read_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (5,'forum_read_subforum','forum_read_subforum.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (6,'forum_unread','forum_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (7,'forum_unread_locked','forum_unread_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (8,'forum_unread_subforum','forum_unread_subforum.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (9,'topic_moved','topic_moved.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (10,'topic_read','topic_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (11,'topic_read_mine','topic_read_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (12,'topic_read_hot','topic_read_hot.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (13,'topic_read_hot_mine','topic_read_hot_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (14,'topic_read_locked','topic_read_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (15,'topic_read_locked_mine','topic_read_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (16,'topic_unread','topic_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (17,'topic_unread_mine','topic_unread_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (18,'topic_unread_hot','topic_unread_hot.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (19,'topic_unread_hot_mine','topic_unread_hot_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (20,'topic_unread_locked','topic_unread_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (21,'topic_unread_locked_mine','topic_unread_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (22,'sticky_read','sticky_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (23,'sticky_read_mine','sticky_read_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (24,'sticky_read_locked','sticky_read_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (25,'sticky_read_locked_mine','sticky_read_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (26,'sticky_unread','sticky_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (27,'sticky_unread_mine','sticky_unread_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (28,'sticky_unread_locked','sticky_unread_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (29,'sticky_unread_locked_mine','sticky_unread_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (30,'announce_read','announce_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (31,'announce_read_mine','announce_read_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (32,'announce_read_locked','announce_read_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (33,'announce_read_locked_mine','announce_read_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (34,'announce_unread','announce_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (35,'announce_unread_mine','announce_unread_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (36,'announce_unread_locked','announce_unread_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (37,'announce_unread_locked_mine','announce_unread_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (38,'global_read','announce_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (39,'global_read_mine','announce_read_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (40,'global_read_locked','announce_read_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (41,'global_read_locked_mine','announce_read_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (42,'global_unread','announce_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (43,'global_unread_mine','announce_unread_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (44,'global_unread_locked','announce_unread_locked.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (45,'global_unread_locked_mine','announce_unread_locked_mine.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (46,'pm_read','topic_read.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (47,'pm_unread','topic_unread.gif','',27,27,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (48,'icon_back_top','icon_back_top.gif','',11,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (49,'icon_contact_aim','icon_contact_aim.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (50,'icon_contact_email','icon_contact_email.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (51,'icon_contact_icq','icon_contact_icq.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (52,'icon_contact_jabber','icon_contact_jabber.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (53,'icon_contact_msnm','icon_contact_msnm.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (54,'icon_contact_www','icon_contact_www.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (55,'icon_contact_yahoo','icon_contact_yahoo.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (56,'icon_post_delete','icon_post_delete.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (57,'icon_post_info','icon_post_info.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (58,'icon_post_report','icon_post_report.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (59,'icon_post_target','icon_post_target.gif','',9,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (60,'icon_post_target_unread','icon_post_target_unread.gif','',9,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (61,'icon_topic_attach','icon_topic_attach.gif','',10,7,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (62,'icon_topic_latest','icon_topic_latest.gif','',9,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (63,'icon_topic_newest','icon_topic_newest.gif','',9,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (64,'icon_topic_reported','icon_topic_reported.gif','',14,16,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (65,'icon_topic_unapproved','icon_topic_unapproved.gif','',14,16,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (66,'icon_user_warn','icon_user_warn.gif','',20,20,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (67,'subforum_read','subforum_read.gif','',9,11,1);
INSERT INTO phpbb_styles_imageset_data (image_id, image_name, image_filename, image_lang, image_height, image_width, imageset_id) VALUES (68,'subforum_unread','subforum_unread.gif','',9,11,1);
INSERT INTO phpbb_styles_template (template_id, template_name, template_copyright, template_path, bbcode_bitfield, template_storedb, template_inherits_id, template_inherit_path) VALUES (1,'prosilver','&copy; phpBB Group','prosilver','lNg=',0,0,'');
INSERT INTO phpbb_styles_theme (theme_id, theme_name, theme_copyright, theme_path, theme_storedb, theme_mtime, theme_data) VALUES (1,'prosilver','&copy; phpBB Group','prosilver',1,0,'');
INSERT INTO phpbb_topics (topic_id, forum_id, icon_id, topic_attachment, topic_approved, topic_reported, topic_title, topic_poster, topic_time, topic_time_limit, topic_views, topic_replies, topic_replies_real, topic_status, topic_type, topic_first_post_id, topic_first_poster_name, topic_first_poster_colour, topic_last_post_id, topic_last_poster_id, topic_last_poster_name, topic_last_poster_colour, topic_last_post_subject, topic_last_post_time, topic_last_view_time, topic_moved_id, topic_bumped, topic_bumper, poll_title, poll_start, poll_length, poll_max_options, poll_last_vote, poll_vote_change) VALUES (1,2,0,0,1,0,'Test Topic',2,972086460,0,0,0,0,0,0,1,'Admin','AA0000',1,2,'Admin','AA0000','Test Topic',972086460,972086460,0,0,0,'',0,0,1,0,0);
INSERT INTO phpbb_topics_posted (user_id, topic_id, topic_posted) VALUES (2,1,1);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (1,1,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (2,2,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (4,2,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (5,2,1,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,3,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,4,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,5,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,6,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,7,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,8,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,9,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,10,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,11,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,12,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,13,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,14,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,15,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,16,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,17,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,18,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,19,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,20,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,21,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,22,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,23,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,24,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,25,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,26,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,28,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,31,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,32,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,34,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,35,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,36,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,37,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,38,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,39,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,41,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,42,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,43,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,44,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,45,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,46,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,48,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,49,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,50,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,51,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,52,0,0);
INSERT INTO phpbb_user_group (group_id, user_id, group_leader, user_pending) VALUES (6,53,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (1,2,1,'',0,'',1170765411,'Anonymous','anonymous','',0,0,'',0,'',0,0,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'d M Y H:i a',1,0,'',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (2,3,5,'',0,'',1170765411,'admin','admin','',0,0,'',0,'',0,0,0,'','',0,0,0,0,0,0,1,'en',0.00,0,'d M Y H:i a',1,1,'AA0000',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,1,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (3,2,6,'',0,'',1170765411,'AdsBot [Google]','adsbot [google]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (4,2,6,'',0,'',1170765411,'Alexa [Bot]','alexa [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (5,2,6,'',0,'',1170765411,'Alta Vista [Bot]','alta vista [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (6,2,6,'',0,'',1170765411,'Ask Jeeves [Bot]','ask jeeves [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (7,2,6,'',0,'',1170765411,'Baidu [Spider]','baidu [spider]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (8,2,6,'',0,'',1170765411,'Exabot [Bot]','exabot [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (9,2,6,'',0,'',1170765411,'FAST Enterprise [Crawler]','fast enterprise [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (10,2,6,'',0,'',1170765411,'FAST WebCrawler [Crawler]','fast webcrawler [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (11,2,6,'',0,'',1170765411,'Francis [Bot]','francis [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (12,2,6,'',0,'',1170765411,'Gigabot [Bot]','gigabot [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (13,2,6,'',0,'',1170765411,'Google Adsense [Bot]','google adsense [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (14,2,6,'',0,'',1170765411,'Google Desktop','google desktop','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (15,2,6,'',0,'',1170765411,'Google Feedfetcher','google feedfetcher','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (16,2,6,'',0,'',1170765411,'Google [Bot]','google [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (17,2,6,'',0,'',1170765411,'Heise IT-Markt [Crawler]','heise it-markt [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (18,2,6,'',0,'',1170765411,'Heritrix [Crawler]','heritrix [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (19,2,6,'',0,'',1170765411,'IBM Research [Bot]','ibm research [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (20,2,6,'',0,'',1170765411,'ICCrawler - ICjobs','iccrawler - icjobs','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (21,2,6,'',0,'',1170765411,'ichiro [Crawler]','ichiro [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (22,2,6,'',0,'',1170765411,'Majestic-12 [Bot]','majestic-12 [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (23,2,6,'',0,'',1170765411,'Metager [Bot]','metager [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (24,2,6,'',0,'',1170765411,'MSN NewsBlogs','msn newsblogs','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (25,2,6,'',0,'',1170765411,'MSN [Bot]','msn [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (26,2,6,'',0,'',1170765411,'MSNbot Media','msnbot media','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (28,2,6,'',0,'',1170765411,'Nutch [Bot]','nutch [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (31,2,6,'',0,'',1170765411,'Online link [Validator]','online link [validator]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (32,2,6,'',0,'',1170765411,'psbot [Picsearch]','psbot [picsearch]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (34,2,6,'',0,'',1170765411,'Sensis [Crawler]','sensis [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (35,2,6,'',0,'',1170765411,'SEO Crawler','seo crawler','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (36,2,6,'',0,'',1170765411,'Seoma [Crawler]','seoma [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (37,2,6,'',0,'',1170765411,'SEOSearch [Crawler]','seosearch [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (38,2,6,'',0,'',1170765411,'Snappy [Bot]','snappy [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (39,2,6,'',0,'',1170765411,'Steeler [Crawler]','steeler [crawler]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (41,2,6,'',0,'',1170765411,'Telekom [Bot]','telekom [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (42,2,6,'',0,'',1170765411,'TurnitinBot [Bot]','turnitinbot [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (43,2,6,'',0,'',1170765411,'Voyager [Bot]','voyager [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (44,2,6,'',0,'',1170765411,'W3 [Sitesearch]','w3 [sitesearch]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (45,2,6,'',0,'',1170765411,'W3C [Linkcheck]','w3c [linkcheck]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (46,2,6,'',0,'',1170765411,'W3C [Validator]','w3c [validator]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (48,2,6,'',0,'',1170765411,'Yacy [Bot]','yacy [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (49,2,6,'',0,'',1170765411,'Yahoo MMCrawler [Bot]','yahoo mmcrawler [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (50,2,6,'',0,'',1170765411,'Yahoo Slurp [Bot]','yahoo slurp [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (51,2,6,'',0,'',1170765411,'Yahoo [Bot]','yahoo [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (52,2,6,'',0,'',1170765411,'YahooSeeker [Bot]','yahooseeker [bot]','',1170765411,0,'',0,'',0,1170765411,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','',0,0,0);
INSERT INTO phpbb_users (user_id, user_type, group_id, user_permissions, user_perm_from, user_ip, user_regdate, username, username_clean, user_password, user_passchg, user_pass_convert, user_email, user_email_hash, user_birthday, user_lastvisit, user_lastmark, user_lastpost_time, user_lastpage, user_last_confirm_key, user_last_search, user_warnings, user_last_warning, user_login_attempts, user_inactive_reason, user_inactive_time, user_posts, user_lang, user_timezone, user_dst, user_dateformat, user_style, user_rank, user_colour, user_new_privmsg, user_unread_privmsg, user_last_privmsg, user_message_rules, user_full_folder, user_emailtime, user_topic_show_days, user_topic_sortby_type, user_topic_sortby_dir, user_post_show_days, user_post_sortby_type, user_post_sortby_dir, user_notify, user_notify_pm, user_notify_type, user_allow_pm, user_allow_viewonline, user_allow_viewemail, user_allow_massemail, user_options, user_avatar, user_avatar_type, user_avatar_width, user_avatar_height, user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield, user_from, user_icq, user_aim, user_yim, user_msnm, user_jabber, user_website, user_occ, user_interests, user_actkey, user_newpasswd, user_form_salt, user_new, user_reminded, user_reminded_time) VALUES (53,2,6,'',0,'',1321022106,'Bing [Bot]','bing [bot]','',1321022106,0,'',0,'',0,1321022106,0,'','',0,0,0,0,0,0,0,'en',0.00,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,0,1,1,0,230271,'',0,0,0,'','','','','','','','','','','','','','','e528469e2ef47bee',0,0,0);
